package Bundle::Simo;
use strict;
use warnings;

$VERSION = '0.0201';

1;

__END__

=head1 NAME

Bundle::Simo - A bundle to install L<Simo> related modules [DISCOURAGED]

=head1 SYNOPSIS

cpan Bundle::Simo

=head1 CONTENTS

Simo - Very simple framework for Object Oriented Perl

Simo::Util - Utility Class for Simo

Simo::Wrapper - Wrapper class to manipulate a object

Simo::Error - Error object for Simo 

Simo::Constrain - Constrain functions for Simo

=head1 AUTHOR

Yuki Kimoto, C<< <kimoto.yuki at gmail.com> >>

=cut 
